@@ -16,9 +16,6 @@ longer need to supplement the User objects as done in `preprocess_data`
 
 @attr.s(auto_attribs=True, kw_only=True)
 class User:
-    # ToDo (Verdan): Make user_id a required field.
-    #  In case if there is only email, id could be email.
-    #  All the transactions and communication will be handled by ID
     user_id: Optional[str] = None
     email: Optional[str] = None
     first_name: Optional[str] = None
@@ -35,6 +32,8 @@ class User:
     manager_id: Optional[str] = None
     role_name: Optional[str] = None
     profile_url: Optional[str] = None
+    profile_picture: Optional[str] = None
+    background_picture: Optional[str] = None
     role: Optional[str] = None
     other_key_values: Optional[Dict[str, str]] = attr.ib(factory=dict)  # type: ignore
     # TODO: Add frequent_used, bookmarked, & owned resources
